@@ -9,7 +9,8 @@ typedef struct {
 	PyObject_HEAD
 
 	//fasta or fastq file path and name
-	char* file_name;
+	//char* file_name;
+	PyObject* file_obj;
 
 	//always output uppercase sequence
 	int uppercase;
