@@ -1,7 +1,7 @@
 #ifndef PYFASTX_FASTQ_KEYS_H
 #define PYFASTX_FASTQ_KEYS_H
-#include "Python.h"
-#include "stdint.h"
+#define PY_SSIZE_T_CLEAN
+#include <Python.h>
 #include "sqlite3.h"
 #include "util.h"
 
@@ -13,11 +13,11 @@ typedef struct {
 	sqlite3_stmt *item_stmt;
 	sqlite3_stmt *in_stmt;
 
-	uint64_t read_counts;
+	Py_ssize_t read_counts;
 } pyfastx_FastqKeys;
 
 extern PyTypeObject pyfastx_FastqKeysType;
 
-PyObject *pyfastx_fastq_keys_create(sqlite3 *index_db, uint64_t read_counts);
+PyObject *pyfastx_fastq_keys_create(sqlite3 *index_db, Py_ssize_t read_counts);
 
 #endif
\ No newline at end of file
