@@ -4,7 +4,7 @@ import pyfastx
 import unittest
 
 join = os.path.join
-data_dir = join(os.path.dirname(__file__), 'data')
+data_dir = join(os.path.dirname(os.path.abspath(__file__)), 'data')
 
 gzip_fastq = join(data_dir, 'test.fq.gz')
 flat_fastq = join(data_dir, 'test.fq')
@@ -52,4 +52,4 @@ class FastxTest(unittest.TestCase):
 
 	def test_exception(self):
 		with self.assertRaises(IndexError):
-			_ = self.keys[self.count]
+			_ = self.keys[self.count*2]
